@@ -16,7 +16,7 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import TaskStatusType
 from .paginator import DescribeObjectsPaginator, ListPipelinesPaginator, QueryObjectsPaginator
@@ -68,14 +68,19 @@ class Exceptions:
     TaskNotFoundException: Type[BotocoreClientError]
 
 
-class DataPipelineClient:
+class DataPipelineClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        DataPipelineClient exceptions.
+        """
 
     def activate_pipeline(
         self,
@@ -87,7 +92,7 @@ class DataPipelineClient:
         """
         Validates the specified pipeline and starts processing pipeline tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#activate_pipeline)
         """
 
@@ -95,7 +100,7 @@ class DataPipelineClient:
         """
         Adds or modifies tags for the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#add_tags)
         """
 
@@ -103,7 +108,7 @@ class DataPipelineClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#can_paginate)
         """
 
@@ -113,7 +118,7 @@ class DataPipelineClient:
         """
         Creates a new, empty pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#create_pipeline)
         """
 
@@ -121,7 +126,7 @@ class DataPipelineClient:
         """
         Deactivates the specified running pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#deactivate_pipeline)
         """
 
@@ -129,7 +134,7 @@ class DataPipelineClient:
         """
         Deletes a pipeline, its pipeline definition, and its run history.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#delete_pipeline)
         """
 
@@ -144,7 +149,7 @@ class DataPipelineClient:
         """
         Gets the object definitions for a set of objects associated with the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#describe_objects)
         """
 
@@ -152,7 +157,7 @@ class DataPipelineClient:
         """
         Retrieves metadata about one or more pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#describe_pipelines)
         """
 
@@ -163,7 +168,7 @@ class DataPipelineClient:
         Task runners call `EvaluateExpression` to evaluate a string in the context of
         the specified object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#evaluate_expression)
         """
 
@@ -177,7 +182,7 @@ class DataPipelineClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#generate_presigned_url)
         """
 
@@ -187,7 +192,7 @@ class DataPipelineClient:
         """
         Gets the definition of the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#get_pipeline_definition)
         """
 
@@ -196,7 +201,7 @@ class DataPipelineClient:
         Lists the pipeline identifiers for all active pipelines that you have permission
         to access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#list_pipelines)
         """
 
@@ -211,7 +216,7 @@ class DataPipelineClient:
         Task runners call `PollForTask` to receive a task to perform from AWS Data
         Pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#poll_for_task)
         """
 
@@ -226,7 +231,7 @@ class DataPipelineClient:
         """
         Adds tasks, schedules, and preconditions to the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#put_pipeline_definition)
         """
 
@@ -243,7 +248,7 @@ class DataPipelineClient:
         Queries the specified pipeline for the names of objects that match the specified
         set of conditions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#query_objects)
         """
 
@@ -251,7 +256,7 @@ class DataPipelineClient:
         """
         Removes existing tags from the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#remove_tags)
         """
 
@@ -262,7 +267,7 @@ class DataPipelineClient:
         Task runners call `ReportTaskProgress` when assigned a task to acknowledge that
         it has the task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#report_task_progress)
         """
 
@@ -273,7 +278,7 @@ class DataPipelineClient:
         Task runners call `ReportTaskRunnerHeartbeat` every 15 minutes to indicate that
         they are operational.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#report_task_runner_heartbeat)
         """
 
@@ -282,7 +287,7 @@ class DataPipelineClient:
         Requests that the status of the specified physical or logical pipeline objects
         be updated in the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.set_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.set_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#set_status)
         """
 
@@ -299,7 +304,7 @@ class DataPipelineClient:
         Task runners call `SetTaskStatus` to notify AWS Data Pipeline that a task is
         completed and provide information about the final status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#set_task_status)
         """
 
@@ -315,7 +320,7 @@ class DataPipelineClient:
         Validates the specified pipeline definition to ensure that it is well formed and
         can be run without error.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#validate_pipeline_definition)
         """
 
@@ -324,20 +329,20 @@ class DataPipelineClient:
         self, operation_name: Literal["describe_objects"]
     ) -> DescribeObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#describeobjectspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_objects"]) -> QueryObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#queryobjectspaginator)
         """
